==> banshee-1-0.99.2.tar.gz: banshee-1-0.99.2/src/Core/Banshee.Core/Banshee.Collection/TrackMediaAttributes.cs <==
//
// TrackMediaAttributes.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2008 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

namespace Banshee.Collection
{
    [Flags]
    public enum TrackMediaAttributes
    {
        None = (0 << 0),
        AudioStream = (1 << 0),
        VideoStream = (1 << 1),
        Music = (1 << 2),
        AudioBook = (1 << 3),
        Podcast = (1 << 4),
        TvShow = (1 << 5),
        Movie = (1 << 6),
        
        Default = AudioStream | Music
    }
}

==> banshee-1-1.4.0.1.tar.gz: banshee-1-1.4.0.1/src/Core/Banshee.Core/Banshee.Collection/TrackMediaAttributes.cs <==
//
// TrackMediaAttributes.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2008 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

namespace Banshee.Collection
{
    [Flags]
    public enum TrackMediaAttributes
    {
        None = (0 << 0),
        AudioStream = (1 << 0), // 1
        VideoStream = (1 << 1), // 2
        Music = (1 << 2),       // 4
        AudioBook = (1 << 3),   // 8
        Podcast = (1 << 4),     // 16
        TvShow = (1 << 5),      // 32
        Movie = (1 << 6),       // 64
        
        Default = AudioStream | Music // 5
    }
}
